@@ -9,5 +9,5 @@ for id in list:
 	elem = Element(hctl, id[1:])
 	info = Info(elem)
 	if info.isUser:
-		print 'Removing element %s' % id
+		print 'Removing element %s' % repr(id)
 		hctl.elementRemove(id[1:])
